@@ -33,59 +33,54 @@ my @op_bookmark_fields = (
 );
 
 my %op_bookmark_fields = map {
+
     # No qr{}x, field names contain significant whitespace
     $_ => qr{^\s+$_=(.*)}
 } @op_bookmark_fields;
 
-sub _parse_file
-{
+sub _parse_file {
     my ($self, $filename) = @_;
 
-    return undef if(!-e $filename);
+    return undef if (!-e $filename);
 
     my $fh;
     my $curitem   = {};
     my $curfolder = {};
     open $fh, "<$filename" or die "Can't open $filename ($!)";
 
-    while (my $line = <$fh>)
-    {
-#        chomp $line;
-        $line =~ s/[\r\n]//g;
-        next if($line =~ /^Opera Hotlist version/);
-        next if($line =~ /^Options:/);
+    while (my $line = <$fh>) {
 
-        if ($line =~ m{^ \s* $}x)
-        {
-            if($curitem->{start})
-            {
+        #        chomp $line;
+        $line =~ s/[\r\n]//g;
+        next if ($line =~ /^Opera Hotlist version/);
+        next if ($line =~ /^Options:/);
+
+        if ($line =~ m{^ \s* $}x) {
+            if ($curitem->{start}) {
                 delete $curitem->{start};
                 $curitem->{parent} = $curfolder->{id};
                 $self->add_bookmark($curitem, $curfolder->{id});
-                if($curitem->{type} eq 'folder')
-                {
+                if ($curitem->{type} eq 'folder') {
                     $curfolder = $curitem;
                 }
                 $curitem = {};
             }
         }
-        if($line eq '-')
-        {
-            $curfolder = $self->{_items}{$curfolder->{parent}};
-#            ($curfolder) = grep { $_->{id} eq $curfolder->{parent} } 
-#                                     @{$self->{_items}};
+        if ($line eq '-') {
+            $curfolder = $self->{_items}{ $curfolder->{parent} };
+
+            #            ($curfolder) = grep { $_->{id} eq $curfolder->{parent} }
+            #                                     @{$self->{_items}};
         }
-        if($line =~/^#(FOLDER|URL)/)
-        {
+        if ($line =~ /^#(FOLDER|URL)/) {
             $curitem->{start} = 1;
             $curitem->{type}  = lc($1);
         }
-        if($curitem->{start})
-        {
+        if ($curitem->{start}) {
             for my $key (keys %op_bookmark_fields) {
                 my $re = $op_bookmark_fields{$key};
                 if ($line =~ $re) {
-                    my $value = $1;
+                    my $value    = $1;
                     my $nicename = lc $key;
                     $nicename =~ s{\s}{_}g;
                     $nicename =~ s{iconfile}{icon};
@@ -96,8 +91,7 @@ sub _parse_file
     }
 
     # Deal with last element if there's no closing empty line
-    if ($curitem->{start})
-    {
+    if ($curitem->{start}) {
         delete $curitem->{start};
         $curitem->{parent} = $curfolder->{id};
         $self->add_bookmark($curitem, $curfolder->{id});
@@ -109,8 +103,7 @@ sub _parse_file
     return $self;
 }
 
-sub get_header_as_string
-{
+sub get_header_as_string {
     my ($self) = @_;
 
     my $header = << "HEADER";
@@ -125,70 +118,66 @@ HEADER
 {
     my $folorder = 0;
 
-    sub get_item_as_string
-    {
+    sub get_item_as_string {
         my ($self, $item) = @_;
 
-        if(!defined $item->{id} || !$self->{_items}{$item->{id}})
-        {
+        if (!defined $item->{id} || !$self->{_items}{ $item->{id} }) {
             warn "No such item in get_item_as_string";
             return;
         }
 
         my $string = '';
-        my ($id, $url, $name, $visited, $created, $modified, $icon, $desc, $expand, $trash, $order) =
-            ($item->{id} || 0,
-             $item->{url} || '',
-             $item->{name} || '',
-             $item->{visited} || 0,
-             $item->{created} || time(),
-             $item->{modified} || 0,
-             $item->{icon} || '',
-             $item->{description} || '',
-             $item->{expanded} || '',
-             $item->{trash} || '',
-             $item->{order} || undef);
+        my ($id, $url, $name, $visited, $created, $modified, $icon, $desc,
+            $expand, $trash, $order) = (
+            $item->{id}          || 0,
+            $item->{url}         || '',
+            $item->{name}        || '',
+            $item->{visited}     || 0,
+            $item->{created}     || time(),
+            $item->{modified}    || 0,
+            $item->{icon}        || '',
+            $item->{description} || '',
+            $item->{expanded}    || '',
+            $item->{trash}       || '',
+            $item->{order}       || undef
+            );
 
-        if($item->{type} eq 'folder')
-        {
-            if(!defined($order))
-            {
+        if ($item->{type} eq 'folder') {
+            if (!defined($order)) {
                 $folorder = 0;
             }
             $string .= "#FOLDER\n";
             $string .= "        ID=$id\n";
             $string .= "        NAME=$name\n";
             $string .= "        CREATED=$created\n";
-            $string .= "        TRASH FOLDER=$trash\n" if($trash);
-            $string .= "        VISITED=$visited\n"    if($visited);
-            $string .= "        EXPANDED=$expand\n"    if($expand);
-            $string .= "        DESCRIPTION=$desc\n"   if($desc);
-            $string .= "        ICONFILE=$icon\n"      if($icon);
-            $string .= "        ORDER=$order\n"        if(defined $order);
+            $string .= "        TRASH FOLDER=$trash\n" if ($trash);
+            $string .= "        VISITED=$visited\n" if ($visited);
+            $string .= "        EXPANDED=$expand\n" if ($expand);
+            $string .= "        DESCRIPTION=$desc\n" if ($desc);
+            $string .= "        ICONFILE=$icon\n" if ($icon);
+            $string .= "        ORDER=$order\n" if (defined $order);
             $string .= "\n";
 
             $string .= $self->get_item_as_string($self->{_items}{$_})
-                foreach (@{$item->{children}});
+                foreach (@{ $item->{children} });
             $string .= "-\n";
         }
-        elsif($item->{type} eq 'url')
-        {
-            if(!defined($order))
-            {
+        elsif ($item->{type} eq 'url') {
+            if (!defined($order)) {
                 $order = $folorder++;
             }
 
             $string .= "#URL\n";
             $string .= "        ID=$id\n";
             $string .= "        NAME=$name\n";
-            $string .= "        URL=$url\n"            if($url);
+            $string .= "        URL=$url\n" if ($url);
             $string .= "        CREATED=$created\n";
-            $string .= "        TRASH FOLDER=$trash\n" if($trash);
-            $string .= "        VISITED=$visited\n"    if($visited);
-            $string .= "        EXPANDED=$expand\n"    if($expand);
-            $string .= "        DESCRIPTION=$desc\n"   if($desc);
-            $string .= "        ICONFILE=$icon\n"      if($icon);
-            $string .= "        ORDER=$order\n"        if(defined $order);
+            $string .= "        TRASH FOLDER=$trash\n" if ($trash);
+            $string .= "        VISITED=$visited\n" if ($visited);
+            $string .= "        EXPANDED=$expand\n" if ($expand);
+            $string .= "        DESCRIPTION=$desc\n" if ($desc);
+            $string .= "        ICONFILE=$icon\n" if ($icon);
+            $string .= "        ORDER=$order\n" if (defined $order);
             $string .= "\n";
         }
 
